import bpy
from . import gui_layout_creator
from . import auto_rigger_settings


class OBJECT_PT_AutoRigger(bpy.types.Panel):
    """Creates a Panel in the Object properties window"""
    bl_label = "Auto Rigger Panel V2"
    bl_idname = "OBJECT_PT_AutoRigger"
    bl_space_type = 'PROPERTIES'
    bl_region_type = 'WINDOW'
    bl_context = "data"

    @classmethod
    def poll(cls, context):
        return context.object.mode == 'POSE'

    # Responsbile for drawing the UI for the Auto Rigger Panel
    def draw(self, context):

        def spine_box(lay, reference,arm):
            # Iterates through the number of spine bones via the number of spine bones prop
            for i in range(reference.NumberOfSpineBones):
                row = lay.row()

                # Creates the index of the spine bone it's looking for as well as the name of the laber
                bone_index = "Spine_" + str(i)
                bone_name = "Spine " + str(i+1)

                # Grabs that spine bone and sets it
                row.prop_search(reference, bone_index, arm, "bones", text=bone_name)

        def bone_row(lay, reference,arm, array,box_name):
            layout = self.layout.box()
            layout.alignment = "CENTER"
            layout.label(text=box_name)
            row = layout.row()
            gui_layout_creator.GuiLayoutCreator.create_horizontal_fields(gui_layout_creator, layout, array,
                                                                         reference, arm)

        # Stores the class that stores the property info as well as the armature data
        reference = bpy.context.scene.ArmatureProp
        arm = bpy.data.objects[bpy.context.object.name].data

        auto_rigger_settings.Arm_name = bpy.data.objects[bpy.context.object.name].name


        # Creates a box for loading in rig files


        # Arrays that handle subsections of the body
        main_bones = ["Head", "Neck", "Pelvis"]
        spine_bones = ["Spine_0", "Spine_1", "Spine_2", "Spine_3", "Spine_4", "Spine_5"]
        left_arm_bones = ["Left_Collar", "Left_Upper_Arm", "Left_Lower_Arm", "Left_Hand"]
        right_arm_bones = ["Right_Collar", "Right_Upper_Arm", "Right_Lower_Arm", "Right_Hand"]
        left_leg_bones = ["Left_Thigh", "Left_Knee", "Left_Foot"]
        right_leg_bones = ["Right_Thigh", "Right_Knee", "Right_Foot"]
        left_toe_bone = ["Left_Toe"]
        right_toe_bone = ["Right_Toe"]
        left_finger_bones = ["Left_Base_Index_Finger", "Left_Base_Middle_Finger", "Left_Base_Ring_Finger", "Left_Base_Pinky_Finger", "Left_Base_Thumb"]
        right_finger_bones = ["Right_Base_Index_Finger", "Right_Base_Middle_Finger", "Right_Base_Ring_Finger", "Right_Base_Pinky_Finger", "Right_Base_Thumb"]

        layout = self.layout

        # Creates a layout box to store extra options the user wants to use
        box = layout.box()
        row = box.row()
        row.alignment = "CENTER"
        row.label(text="Extra Options")

        # Creates a button to store the option to use FK/IK Sliders and custom bones
        row = box.row()
        row.prop(reference,"UseFKIKControllers", text="Add FK IK Sliders?")
        row.prop(reference,"CleanRig", text="Clean Rig?")

        # Next row handles loading and saving rig files
        col = box.row()
        col.prop(reference,"LoadRigFile", text="Load Rig File?")
        col.prop(reference,"SaveRigFile", text="Save To Rig File?")

        # Next row handles loading and saving rig files
        new_row = box.row()
        new_row.prop(reference,"NoFingers", text="Model Has No Fingers?")
        new_row.prop(reference,"NoToes", text="Model Has No Toes?")

        second_new_row = box.row()
        second_new_row.prop(reference,"AddCustomBoneShapes", text="Add Custom Bone Shapes?")

        # Determines to load or save a rig file
        if reference.LoadRigFile is True:

            # Line 49 - 56 handles creating a box where the user can load in their rig file
            box = layout.box()
            row = box.row()
            row.alignment = "CENTER"
            row.label(text="Load Rig File")

            row = box.row()
            row.prop(reference,"FileToLoad", text="File Path")
            row = box.row()
            row.operator("object.load_auto_rig_file")


        #Determines if the info should be saved
        elif reference.SaveRigFile is True:

            # Line 49 - 56 handles creating a box where the user can load in their rig file
            box = layout.box()
            row = box.row()
            row.alignment = "CENTER"
            row.label(text="Save Info To Rig File")

            row = box.row()
            row.prop(reference, "FileDirectoryToSaveInto", text="File Directory")
            row = box.row()
            row.prop(reference, "FileName", text="File Name")
            row = box.row()
            row.operator("object.save_auto_rig_file")




        # Creates the various rows for the bone panel
        bone_row(layout, reference, arm, main_bones,"Main Bones")

        # Line 49 - 56 handles creating a box where the user can load in their rig file
        box = layout.box()
        row = box.row()
        row.alignment = "CENTER"
        row.label(text="Spine Bones")

        row = box.row()
        row.prop(reference, "NumberOfSpineBones", text="Spine Bones Number")
        number_of_spine_bones = reference.NumberOfSpineBones
        print(reference.NumberOfSpineBones)

        # This is just to add a space between the properties
        row = box.row()
        row = row.row()
        spine_box(box, reference, arm,)


        #bone_row(layout, reference, arm, spine_bones,"Spine Bones")

        # Split the arm groups between left and right
        gui_layout_creator.GuiLayoutCreator.create_split_boxes(gui_layout_creator, layout, left_arm_bones,
                                                               "Left Arm", right_arm_bones, "Right Arm", reference, arm)

        #         # Split the leg groups between left and right
        gui_layout_creator.GuiLayoutCreator.create_split_boxes(gui_layout_creator, layout, left_leg_bones,
                                                               "Left Leg", right_leg_bones, "Right Leg", reference, arm)

        #         # Split the leg groups between left and right
        if reference.NoFingers is False:
            gui_layout_creator.GuiLayoutCreator.create_split_boxes(gui_layout_creator, layout, left_finger_bones,
                                                               "Left Left Fingers", right_finger_bones, "Right Fingers", reference, arm)
        if reference.NoToes is False:
            gui_layout_creator.GuiLayoutCreator.create_split_boxes(gui_layout_creator, layout, left_toe_bone,
                                                               "Left Toe Bone", right_toe_bone, "Right Toe Bone", reference, arm)


        # Creates a another row to fit extra operators
        # box = layout.box()
        # col = box.row()
        # col.operator("object.auto_rig_scale")

        row = layout.row()
        row.operator("object.auto_rig")




