from pathlib import Path

import bpy
import json
import os
from os.path import abspath, dirname, join
from . import rig_fixer
from . import  auto_rigger_validator
from . import auto_rigger_settings
from . import auto_rigger_ik_limbs
from . import auto_rigger_fk_ik_controls
from . import  auto_rigger_custom_shapes
from os import path


class SaveRigFile(bpy.types.Operator):
    bl_idname = "object.save_auto_rig_file"
    bl_label = "Save Auto Rig File"

    def execute(self, context):
        # Gets the armature prop property used in the scene and the bone files
        reference = bpy.context.scene.ArmatureProp
        arm = bpy.data.objects[bpy.context.object.name].data

        # Converts the file name to the Json file format as well as getting the absolute path
        file_name = reference.FileName + '.json'
        file_directory = reference.FileDirectoryToSaveInto
        converted_directory = os.path.realpath(bpy.path.abspath(file_directory))

        dict1 = {
            "Head": reference.Head,
            "Neck": reference.Neck,
            "Pelvis": reference.Pelvis,
            "Spine_0": reference.Spine_0,
            "Spine_1": reference.Spine_1,
            "Spine_2": reference.Spine_2,
            "Spine_3": reference.Spine_3,
            "Spine_4": reference.Spine_4,
            "Spine_5": reference.Spine_5,
            "Left_Collar": reference.Left_Collar,
            "Left_Upper_Arm": reference.Left_Upper_Arm,
            "Left_Lower_Arm": reference.Left_Lower_Arm,
            "Left_Hand": reference.Left_Hand,
            "Right_Collar": reference.Right_Collar,
            "Right_Upper_Arm": reference.Right_Upper_Arm,
            "Right_Lower_Arm": reference.Right_Lower_Arm,
            "Right_Hand": reference.Right_Hand,
            "Left_Thigh": reference.Left_Thigh,
            "Left_Knee": reference.Left_Knee,
            "Left_Foot": reference.Left_Foot,
            "Left_Toe": reference.Left_Toe,
            "Right_Thigh": reference.Right_Thigh,
            "Right_Knee": reference.Right_Knee,
            "Right_Foot": reference.Right_Foot,
            "Right_Toe": reference.Right_Toe,
            "Left_Base_Index_Finger" : reference.Left_Base_Index_Finger,
            "Left_Base_Middle_Finger": reference.Left_Base_Middle_Finger,
            "Left_Base_Ring_Finger" : reference.Left_Base_Ring_Finger,
            "Left_Base_Pinky_Finger" : reference.Left_Base_Pinky_Finger,
            "Left_Base_Thumb" : reference.Left_Base_Thumb,
            "Right_Base_Index_Finger": reference.Right_Base_Index_Finger,
            "Right_Base_Middle_Finger": reference.Right_Base_Middle_Finger,
            "Right_Base_Ring_Finger": reference.Right_Base_Ring_Finger,
            "Right_Base_Pinky_Finger": reference.Right_Base_Pinky_Finger,
            "Right_Base_Thumb": reference.Right_Base_Thumb,

        }

        # the json file where the output must be stored

        with open(join(converted_directory, file_name), 'w+') as f:
            json.dump(dict1, f)
        f.close()

        # Displays a sucess message when the armature has been rigged
        self.report({'INFO'}, 'Successfilly Saved ' + reference.FileName + '!')

        return {'FINISHED'}
