import bpy
from bpy.props import (StringProperty,
                       BoolProperty,
                       IntProperty,
                       FloatProperty,
                       EnumProperty,
                       PointerProperty,
                       CollectionProperty,
                       FloatVectorProperty
                       )


# Armature Data Properties: Stores string properties to be used by the UI
class BonesPointer(bpy.types.PropertyGroup):

    #Ints to store specific info
    NumberOfSpineBones: IntProperty(name="NumberOfSpineBones")

    # String to store file path
    FileDirectoryToSaveInto: StringProperty(name="savefile" , subtype="DIR_PATH")
    FileToLoad: StringProperty(name="filedirectory" , subtype="FILE_PATH")
    FileName: StringProperty(name="filename")


    # Bools used to determine extra modes of operation
    UseFKIKControllers: BoolProperty(name="UseFKIKControllers")
    AddCustomBoneShapes: BoolProperty(name="UseCustomBoneShapes")
    CleanRig: BoolProperty(name="CleanRig")

    LoadRigFile: BoolProperty(name="LoadRigFile")
    SaveRigFile: BoolProperty(name="SaveRigFile")
    NoFingers: BoolProperty(name= "NoFingers")
    NoToes: BoolProperty(name= "NoToes")



    # Head and Neck Bones
    Head: StringProperty(name="Head")
    Neck: StringProperty(name="Neck")

    # Spine Bones
    NumberOfSpineBones: IntProperty(name="NumberOfSpineBones", default=1 ,  min=1, max= 6)
    Spine_0: StringProperty(name="Spine_0")
    Spine_1: StringProperty(name="Spine_1")
    Spine_2: StringProperty(name="Spine_2")
    Spine_3: StringProperty(name="Spine_3")
    Spine_4: StringProperty(name="Spine_4")
    Spine_5: StringProperty(name="Spine_5")

    # Pelvis
    Pelvis: StringProperty(name="Pelvis")

    # Left Arm Bones
    Left_Collar: StringProperty(name="Left_Collar")
    Left_Upper_Arm: StringProperty(name="Left_Upper_Arm")
    Left_Lower_Arm: StringProperty(name="Left_Lower_Arm")
    Left_Hand: StringProperty(name="Left_Hand")

    # Right Arm Bones
    Right_Collar: StringProperty(name="Right_Collar")
    Right_Upper_Arm: StringProperty(name="Right_Upper_Arm")
    Right_Lower_Arm: StringProperty(name="Right_Lower_Arm")
    Right_Hand: StringProperty(name="Right_Hand")

    # Left Leg Bones
    Left_Thigh: StringProperty(name="Left_Thigh")
    Left_Knee: StringProperty(name="Left_Knee")
    Left_Foot: StringProperty(name="Left_Foot")
    Left_Toe: StringProperty(name="Left_Toe")

    # Right Leg Bones
    Right_Thigh: StringProperty(name="Right_Thigh")
    Right_Knee: StringProperty(name="Right_Knee")
    Right_Foot: StringProperty(name="Right_Foot")
    Right_Toe: StringProperty(name="Right_Toe")


    #Finger Bones
    Left_Base_Index_Finger: StringProperty(name="Left Index Finger")
    Left_Base_Middle_Finger: StringProperty(name="Left Middle Finger")
    Left_Base_Ring_Finger: StringProperty(name="Left Ring Finger")
    Left_Base_Pinky_Finger: StringProperty(name="Left Pinky Finger")
    Left_Base_Thumb: StringProperty(name="Left Thumb")

    Right_Base_Index_Finger: StringProperty(name="Right Index Finger")
    Right_Base_Middle_Finger: StringProperty(name="Right Middle Finger")
    Right_Base_Ring_Finger: StringProperty(name="Right Ring Finger")
    Right_Base_Pinky_Finger: StringProperty(name="Right Pinky Finger")
    Right_Base_Thumb: StringProperty(name="Right Thumb")


    # Rig Colors
    #Arm_Color: FloatVectorProperty(name="myColor", subtype="COLOR")
